
global data "C:\Users\evanjtaylor\Documents\Dakotas\data"

use "$data\Dakotas_Mail_Cat.dta", clear


keep if race==1
replace rail_1900 = 0 if rail_1930 == 0
gen rail_new = rail_1930 == 1 & rail_1900 == 0 if rail_1930<.
keep if live_75<. & ornp<. & mail_cat<.

gen count=1 
collapse (sum) count, by(sor)

gen state_fips = sor
replace state_fips = state_fips+1 if sor>=3
replace state_fips = state_fips+1 if sor>=6
replace state_fips = state_fips+1 if sor>=12
replace state_fips = 51 if sor==49

tempfile states
save `states'




tempfile all

foreach year of numlist 90/95 {
clear
import sasxport "$data\cdbrfs`year'xpt\CDBRFS`year'.XPT"

keep _state race hispanic sex iyear age educa drinkany drinkge5 drinkdri _rfdrchr _smoker _rfsmok* smoke100

keep if race==1
keep if hispanic==2
destring iyear, replace
replace iyear = 1900+iyear
keep if inrange(iyear-age,1916,1927)
gen datayear = `year'+1900
capture append using `all'
save `all', replace

}

foreach year in 96 97 98 99 00 {
clear
import sasxport "$data\cdbrfs`year'xpt\CDBRFS`year'.XPT"

keep _state race hispanic sex iyear age educa drinkany drinkge5 drinkdri _rfdrchr _smoker _rfsmok* smoke100

keep if race==1
keep if hispanic==2
destring iyear, replace
replace iyear = 1900+iyear if iyear<100
keep if inrange(iyear-age,1916,1927)
gen datayear=`year' + 1900
replace datayear=2000 if datayear==1900
capture append using `all'
save `all', replace


}

gen EDUC = .
/* Less than HS */
replace EDUC = 1 if inrange(educa,1,2) & inrange(datayear,1990,1992)
replace EDUC = 1 if inrange(educa,1,3) & inrange(datayear,1993,2000)

/* HS */
replace EDUC = 2 if educa==3 & inrange(datayear,1990,1992)
replace EDUC = 2 if educa==4 & inrange(datayear,1993,2000)

/* Some College */
replace EDUC = 3 if inrange(educa,4,6) & inrange(datayear,1990,1992)
replace EDUC = 3 if educa==5 & inrange(datayear,1993,2000)

/* College */
replace EDUC = 4 if inrange(educa,7,8) & inrange(datayear,1990,1992)
replace EDUC = 4 if educa==6 & inrange(datayear,1993,2000)

gen EDUC2 = ceil(EDUC/2)


/* Any drinks past month */
gen DRINK_MO = 2-drinkany if inrange(drinkany,1,2)  /* 1=YES, 2=NO, other dropped */

/* Binge drink past month (create binary for at least once */
gen BINGE_MO = 0 if drinkge5==88
replace BINGE_MO = 1 if inrange(drinkge5,1,76)

/* Drink and drive past month */
gen DRIVE_DR = 0 if drinkdri==88
replace DRIVE_DR = 1 if inrange(drinkdri,1,76)

/* Current Smoker */
/* years 1990-1993 */
gen CURR_SMOKER = 1 if _smoker==1 | _smoker==4  /* Current and irregular */
replace CURR_SMOKER = 0 if inrange(_smoker,2,3)
/* years 1994-1995*/
replace CURR_SMOKER = 1 if inrange(_smoker2,1,4) & inrange(datayear,1994,1995)
replace CURR_SMOKER = 0 if inrange(_smoker2,5,6) & inrange(datayear,1994,1995)
/* year 1996-2000 */
replace CURR_SMOKER = 1 if inrange(_smoker2,1,2) & inrange(datayear,1996,2000)
replace CURR_SMOKER = 0 if inrange(_smoker2,3,4) & inrange(datayear,1996,2000)


/* Ever Smoker */
gen EVER_SMOKER = CURR_SMOKER

/* years 1990-1993 */
replace EVER_SMOKER = 1 if _smoker==2
/* years 1994-1995*/
replace EVER_SMOKER = 1 if _smoker2==5 & inrange(datayear,1994,1995)
/* year 1996-2000 */
replace EVER_SMOKER = 1 if _smoker2==3 & inrange(datayear,1996,2000)

/* SMOKE 100 */
gen SMOKE100 = 1 if smoke100 == 1
replace SMOKE100 = 0 if smoke100 == 2

drop if EDUC==.
drop if _state==72 /* PR */

foreach var of varlist DRINK_MO BINGE_MO DRIVE_DR CURR_SMOKER EVER_SMOKER SMOKE100  {
gen num_`var' = `var'<.
}

collapse (mean) DRINK_MO BINGE_MO DRIVE_DR CURR_SMOKER EVER_SMOKER SMOKE100 ///
 (sum) num_*, by(sex EDUC2 _state)


rename _state state_fips
merge m:1 state_fips using `states'

drop if state_fips==27 /* Remove Minnesota, Can't tell if migrant or not */

gen migrant = 1-inlist(state_fips,16,19,30,31,38,46,56)
egen count_mig = sum(count), by(sex EDUC2 migrant)
gen weight_mig = count/count_mig

foreach var of varlist DRINK_MO BINGE_MO DRIVE_DR CURR_SMOKER EVER_SMOKER SMOKE100  {
egen tot_`var' = sum(num_`var'), by(sex EDUC2 migrant)
gen var_`var'_ = `var'*(1-`var')/num_`var'*weight_mig^2
egen var_`var' = sum(var_`var'), by(sex EDUC2 migrant)
drop var_`var'_
}



collapse (mean) DRINK_MO BINGE_MO DRIVE_DR CURR_SMOKER EVER_SMOKER SMOKE100 tot_* var_* [fw=count], by(sex EDUC2 migrant)
foreach var of varlist DRINK_MO BINGE_MO DRIVE_DR CURR_SMOKER EVER_SMOKER SMOKE100  {
gen se_`var' = var_`var' ^ 0.5
}

