/* Run bootstrap on the all MTE estimators */

global data "C:\Users\evanjtaylor\Documents\Dakotas\data"
global dofile "C:\Users\evanjtaylor\Documents\Dakotas\dofile"

/* To run on uchicago server */
*global data "/mnt/fs0/home/evant/Dakotas/data"
*global dofile "/mnt/fs0/home/evant/Dakotas/dofile"



cap log close
log using $dofile/dakota_bootstrap.txt, replace text
set seed 12345678

use $data/Dakotas_Mail_Cat.dta, clear


keep if race==1
replace rail_1900 = 0 if rail_1930 == 0
gen rail_new = rail_1930 == 1 & rail_1900 == 0 if rail_1930<.
keep if live_75<. & ornp<. & mail_cat<.

merge m:1 county statefip using $data/newcontrols011018.dta

replace pop1930 = pop1930/1000 /* Made pop1930 in 1000's */

foreach var of varlist pop1930 frac_radio30 frac_farm30 hhsize30 {
gen sq_`var' = `var'^2
gen cu_`var' = `var'^3
}

gen popradio = pop1930*frac_radio30
gen popfarm = pop1930*frac_farm30
gen pophh = pop1930*hhsize30
gen radiofarm = frac_radio30*frac_farm30
gen radiohh = frac_radio30*hhsize30
gen farmhh = frac_farm30*hhsize30


egen cohort_sex = group(birthyr sex born_ND born_SD)
tab cohort_sex, gen(cs_)

local xcontrol pop1930 frac_radio30 frac_farm30 hhsize30 sq_* cu_* ///
popradio popfarm pophh radiofarm radiohh farmhh cs_1-cs_71 


/* Semiparametric MTE Estimator */
keep ornp mail_cat `xcontrol' live_75 feature_id rail_1900




tempfile all results
save `all'

clear
set obs 1
gen int U_D_int = 500
save `results'

forvalues bootdraw = 1/100 {



use `all', clear
bsample, cluster(feature_id)

/* Logit first stage */
logit ornp i.mail_cat rail_1900 `xcontrol'
predict phat

qui gen phat2 = phat^2
qui gen phat3 = phat^3 


* De-mean the X variables

foreach var of varlist live_75 `xcontrol' {
sum `var'
qui gen m_`var' = `var' - r(mean)
}

qui gen U_D = .

* qui generate for semi-parametric regressions 
qui gen phat_round = round(phat,.01)
egen Z_group = group(phat_round)
egen id = tag(Z_group)
qui gen phat_ = phat_round if id==1

forvalues j = 0/1 {
qui gen val075_`j' = .
qui gen mte075_`j' = .
qui gen valp2_`j' = .
qui gen mtep2_`j' = .





* Quadratic residualize
foreach var of varlist live_75 `xcontrol' {
qui reg `var' phat phat2 if ornp==`j'
predict rq`j'_`var', resid
}
qui reg rq`j'_* if ornp==`j'
drop rq`j'_*
mat bq = e(b)
qui gen resquad_Y`j' = live_75 if ornp==`j'
local counter = 1
foreach var of varlist `xcontrol' {
replace resquad_Y`j' = resquad_Y`j' - bq[1,`counter']*m_`var'
local counter = `counter'+1
}



* Non-parametric residualize (bw =  .075)
* Generate groups by P (to help with computation speed) will give each observation
* the predicted value at the closest rounded p_hat 




* Bandwidth .075
foreach var of varlist live_75 `xcontrol' {

lpoly `var' phat if ornp==`j', bw(.075) gen(pnb`j'_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pnb`j'_`var' = mean(pnb`j'_`var'_), by(Z_group)
qui gen rnb`j'_`var' = `var'-pnb`j'_`var' if ornp==`j'

di "`var'"
}
qui reg rnb`j'_* if ornp==`j'
drop rnb`j'_* pnb`j'_*
mat bnb = e(b)
qui gen resnonb_Y`j' = live_75
local counter = 1
foreach var of varlist `xcontrol' {
replace resnonb_Y`j' = resnonb_Y`j' - bnb[1,`counter']*m_`var'
local counter = `counter'+1
}

}   /* j loop */




/* Local IV estimators  */

* Generate interaction variables (for heterogeneous treatment effects)
foreach var of varlist `xcontrol' {
gen PH_`var' = `var' * phat
qui gen m_PH_`var' = m_`var' * phat
}



* Quadratic residualize
foreach var of varlist live_75 `xcontrol' PH_*  {
qui reg `var' phat phat2
predict rq_`var', resid
}
qui reg rq_*
drop rq_*
mat bq = e(b)
qui gen resquad_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_*  {
replace resquad_Y = resquad_Y - bq[1,`counter']*m_`var'
local counter = `counter'+1
}




* Bandwidth .075
foreach var of varlist live_75 `xcontrol'  PH_*  {

lpoly `var' phat, bw(.075) gen(pnb_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pnb_`var' = mean(pnb_`var'_), by(Z_group)
qui gen rnb_`var' = `var'-pnb_`var'

di "`var'"
}
qui reg rnb_*
drop rnb_* pnb_*
mat bnb = e(b)
qui gen resnonb_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_* {
replace resnonb_Y = resnonb_Y - bnb[1,`counter']*m_`var'
local counter = `counter'+1
}


* Calculate marginal treatment effects
qui gen liv_val075 = .
qui gen liv_mte075 = .
qui gen liv_valp2 = .
qui gen liv_mtep2 = .

sum phat_round
local pmin = r(min)
local pmax = r(max)


local counter = 1

forvalues x = `pmin'(.005)`pmax' {

replace U_D = `x' in `counter'

qui reg resnonb_Y1 phat phat2 if inrange(phat,`x'-.075,`x'+.075)& ornp==1
mat b = e(b)
replace val075_1 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte075_1 = 2*`x'*b[1,1]+3*`x'^2*b[1,2]+b[1,3] in `counter'

qui reg resnonb_Y0 phat phat2 if inrange(phat,`x'-.075,`x'+.075) & ornp==0
mat b = e(b)
replace val075_0 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte075_0 = val075_0 + (`x'-1)*(b[1,1]+2*`x'*b[1,2]) in `counter'



qui reg resnonb_Y phat phat2 if inrange(phat,`x'-.075,`x'+.075)
mat b = e(b)
replace liv_val075 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace liv_mte075 = b[1,1]+2*`x'*b[1,2] in `counter'


local counter = `counter' + 1

}

/* Calculate polynomial MTE */


qui reg resquad_Y1 phat phat2 if ornp==1
mat b = e(b)
replace valp2_1 = U_D*b[1,1]+U_D^2*b[1,2]+b[1,3] if U_D<.
replace mtep2_1 = U_D*(b[1,1]+2*U_D*b[1,2])+valp2_1 if U_D<.

qui reg resquad_Y0 phat phat2 if ornp==0
mat b = e(b)
replace valp2_0 = U_D*b[1,1]+U_D^2*b[1,2]+b[1,3] if U_D<.
replace mtep2_0 = (U_D-1)*(b[1,1]+2*U_D*b[1,2])+valp2_0 if U_D<.



qui reg resquad_Y phat phat2
mat b = e(b)
replace liv_valp2 = U_D*b[1,1]+U_D^2*b[1,2]+b[1,3] if U_D<.
replace liv_mtep2 = b[1,1]+2*U_D*b[1,2] if U_D<.


foreach ty in "p2" "075"  {
qui gen mte`ty' = mte`ty'_1 - mte`ty'_0
}


keep val* mte* liv_val* liv_mte* U_D
keep if U_D<.
qui gen int U_D_int = round(U_D * 1000,1)

foreach var of varlist val* mte* liv_val* liv_mte* {
rename `var' b`bootdraw'_`var'
}



di `bootdraw'

merge 1:1 U_D_int using `results'
drop _merge
save `results', replace

save $data/dakota_bootstrap.dta, replace

} /* bootstrap loop */

save $data/dakota_bootstrap.dta, replace
 
 
