/* This do-file creates the propensity score histograms (Figure 4) */

global data "C:\Users\evanjtaylor\Documents\Dakotas\data"
global dofile "C:\Users\evanjtaylor\Documents\Dakotas\dofile"
global output "C:\Users\evanjtaylor\Documents\Dakotas\output"

cap log close
log using $output\dakota_histogram.txt, replace text
set seed 123456789

use $data\Dakotas_Mail_Cat.dta, clear


keep if race==1 & ornp<. & live_75<. 
replace rail_1900 = 0 if rail_1930 == 0
gen rail_new = rail_1930 == 1 & rail_1900 == 0 if rail_1930<.

merge m:1 county statefip using $data\newcontrols011018.dta

replace pop1930 = pop1930/1000 /* Made pop1930 in 1000's */

foreach var of varlist pop1930 frac_radio30 frac_farm30 hhsize30 {
gen sq_`var' = `var'^2
gen cu_`var' = `var'^3
}

gen popradio = pop1930*frac_radio30
gen popfarm = pop1930*frac_farm30
gen pophh = pop1930*hhsize30
gen radiofarm = frac_radio30*frac_farm30
gen radiohh = frac_radio30*hhsize30
gen farmhh = frac_farm30*hhsize30


egen cohort_sex = group(birthyr sex born_ND born_SD)
tab cohort_sex, gen(cs_)

local xcontrol pop1930 frac_radio30 frac_farm30 hhsize30 sq_* cu_* ///
popradio popfarm pophh radiofarm radiohh farmhh cs_1-cs_71



logit ornp rail_1900 rail_new `xcontrol'
predict phat_r

twoway (histogram phat_r if ornp==1, start(.3) width(.01) color(green) freq) ///
       (histogram phat_r if ornp==0, start(.3) width(.01) freq ///
	   fcolor(none) lcolor(black)), legend(order(1 "Migrants" 2 "Non-Migrants" ))
graph save $output/histogram_prop_rail, replace
/* Figure 4, Panel A */

logit ornp i.mail_cat `xcontrol'
predict phat_m
twoway (histogram phat_m if ornp==1, start(.34) width(.01) color(green) freq) ///
       (histogram phat_m if ornp==0, start(.34) width(.01) freq ///
	   fcolor(none) lcolor(black)), legend(order(1 "Migrants" 2 "Non-Migrants" ))
graph save $output/histogram_prop_mail, replace
/* Figure 4, Panel B */


logit ornp i.mail_cat rail_new  `xcontrol', cluster(feature_id)

twoway (histogram phat if ornp==1, start(.3) width(.01) color(green) freq) ///
       (histogram phat if ornp==0, start(.3) width(.01) freq ///
	   fcolor(none) lcolor(black)), legend(order(1 "Migrants" 2 "Non-Migrants" ))
graph save $output/histogram_prop_both, replace
/* Figure 4, Panel C */

log close

