* This do-file calculates the IV weights for the different instruments */
/* Creates Figure 8 */

global data "C:\Users\evanjtaylor\Documents\Dakotas\data"
global dofile "C:\Users\evanjtaylor\Documents\Dakotas\dofile"
global output "C:\Users\evanjtaylor\Documents\Dakotas\output"

cap log close
log using $output\dakota_iv_weights.txt, replace text
set seed 123456789

use $data\Dakotas_Mail_Cat.dta, clear


keep if race==1 & ornp<.
replace rail_1900 = 0 if rail_1930 == 0
gen rail_new = rail_1930 == 1 & rail_1900 == 0 if rail_1930<.

merge m:1 county statefip using $data\newcontrols011018.dta

replace pop1930 = pop1930/1000 /* Made pop1930 in 1000's */

foreach var of varlist pop1930 frac_radio30 frac_farm30 hhsize30 {
gen sq_`var' = `var'^2
gen cu_`var' = `var'^3
}

gen popradio = pop1930*frac_radio30
gen popfarm = pop1930*frac_farm30
gen pophh = pop1930*hhsize30
gen radiofarm = frac_radio30*frac_farm30
gen radiohh = frac_radio30*hhsize30
gen farmhh = frac_farm30*hhsize30


egen cohort_sex = group(birthyr sex born_ND born_SD)
tab cohort_sex, gen(cs_)

local xcontrol pop1930 frac_radio30 frac_farm30 hhsize30 sq_* cu_* ///
popradio popfarm pophh radiofarm radiohh farmhh cs_1-cs_71

keep if rail_new<. & live_75<.

logit ornp i.mail_cat rail_new  `xcontrol', cluster(feature_id)
predict phat 

/* Calculate IV weights 

1. Mail instrument
2. Railroad instrument
3. Both
4. Propensity score */



regress ornp i.mail_cat `xcontrol'
predict phat_mail
regress phat_mail `xcontrol'
predict v_mail, resid
gen cov_mail_ = v_mail*phat
egen cov_mail = mean(cov_mail_)
gen w_u_mail = .

regress ornp rail_1900 rail_new `xcontrol'
predict phat_rail
regress phat_rail `xcontrol'
predict v_rail, resid
gen cov_rail_ = v_rail*phat
egen cov_rail = mean(cov_rail_)
gen w_u_rail = .

regress ornp rail_1900 rail_new i.mail_cat `xcontrol'
predict phat_both
regress phat_both `xcontrol'
predict v_both, resid
gen cov_both_ = v_both*phat
egen cov_both = mean(cov_both_)
gen w_u_both = .

regress phat `xcontrol'
predict v_phat, resid
gen cov_phat_ = v_phat*phat
egen cov_phat = mean(cov_phat_)
gen w_u_phat = .

gen ev_mail = .
gen ev_rail = .
gen ev_both = .
gen ev_phat = .


gen _u = _n in 1/99
forvalues x = 1/99 {
quietly sum v_mail if phat> `x'/100
replace ev_mail = r(mean) in `x'
local v_count = r(N) 
replace w_u_mail = ev_mail * (`v_count'/_N) / cov_mail in `x'

quietly sum v_rail if phat> `x'/100
replace ev_rail = r(mean)  in `x'
local v_count = r(N) 
replace w_u_rail = ev_rail * (`v_count'/_N) / cov_rail in `x'

quietly sum v_both if phat> `x'/100
replace ev_both = r(mean)  in `x'
local v_count = r(N) 
replace w_u_both = ev_both * (`v_count'/_N) / cov_both in `x'

quietly sum v_phat if phat> `x'/100
replace ev_phat = r(mean)  in `x'
local v_count = r(N) 
replace w_u_phat = ev_phat * (`v_count'/_N) / cov_phat in `x'
}

replace w_u_mail = 0 if w_u_mail == . & _u<.
replace w_u_rail = 0 if w_u_rail == . & _u<.
replace w_u_both = 0 if w_u_both == . & _u<.
replace w_u_phat = 0 if w_u_phat == . & _u<.

replace _u = . if !inrange(_u,37,71)

twoway (scatter w_u_mail _u, connect(l) msymbol(i)) ///
 (scatter w_u_rail _u, connect(l) msymbol(i))  ///
 (scatter w_u_both _u, connect(l) msymbol(i))  ///
 (scatter  w_u_phat _u, connect(l) msymbol(i))
graph save $output/iv_weights, replace

log close
