/* Use Leave One Out Cross Validation to generate bandwidth for semi-parametric estimator */
global data "C:\Users\evanjtaylor\Documents\Dakotas\data"
global dofile "C:\Users\evanjtaylor\Documents\Dakotas\dofile"
global output "C:\Users\evanjtaylor\Documents\Dakotas\output"

cap log close
log using $dofile\dakota_local_iv.txt, replace text
set seed 123456789

use $data\Dakotas_Mail_Cat.dta, clear


keep if race==1
replace rail_1900 = 0 if rail_1930 == 0
gen rail_new = rail_1930 == 1 & rail_1900 == 0 if rail_1930<.
keep if live_75<. & ornp<. & mail_cat<.

merge m:1 county statefip using $data\newcontrols011018.dta

replace pop1930 = pop1930/1000 /* Made pop1930 in 1000's */

foreach var of varlist pop1930 frac_radio30 frac_farm30 hhsize30 {
gen sq_`var' = `var'^2
gen cu_`var' = `var'^3
}

gen popradio = pop1930*frac_radio30
gen popfarm = pop1930*frac_farm30
gen pophh = pop1930*hhsize30
gen radiofarm = frac_radio30*frac_farm30
gen radiohh = frac_radio30*hhsize30
gen farmhh = frac_farm30*hhsize30


egen cohort_sex = group(birthyr sex born_ND born_SD)
tab cohort_sex, gen(cs_)
egen birth_county = group(county statefip)

local xcontrol pop1930 frac_radio30 frac_farm30 hhsize30 sq_* cu_* ///
popradio popfarm pophh radiofarm radiohh farmhh cs_1-cs_71


/* Semiparametric MTE Estimator */
keep ornp mail_cat `xcontrol' live_75 feature_id birthyr sex born_ND born_SD birth_county rail_new



/* Logit first stage */
logit ornp i.mail_cat rail_new `xcontrol'
predict phat 

xtile cat_phat = phat, n(100)
egen x_phat = mean(phat), by(cat_phat)
egen x_ornp = mean(ornp), by(cat_phat)

gen phat2 = phat^2
gen phat3 = phat^3




* De-mean the X variables
foreach var of varlist live_75 `xcontrol' {
sum `var'
gen m_`var' = `var' - r(mean)
}

* Generate interaction variables (for heterogeneous treatment effects)
foreach var of varlist `xcontrol' {
gen PH_`var' = `var' * phat
gen m_PH_`var' = m_`var' * phat
}


* Linear residualize 
foreach var of varlist live_75 `xcontrol' PH_* {
reg `var' phat
predict rl_`var', resid
}
reg rl_*
mat bl = e(b)
gen reslin_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_*  {
replace reslin_Y = reslin_Y - bl[1,`counter']*m_`var'
local counter = `counter'+1
}

reg reslin_Y phat
reg live_75 phat `xcontrol' m_PH_* 
egen x_live75 = mean(reslin_Y), by(cat_phat)

* Quadratic residualize
foreach var of varlist live_75 `xcontrol' PH_*  {
reg `var' phat phat2
predict rq_`var', resid
}
reg rq_*
mat bq = e(b)
gen resquad_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_*  {
replace resquad_Y = resquad_Y - bq[1,`counter']*m_`var'
local counter = `counter'+1
}

reg resquad_Y phat phat2
reg live_75 phat phat2 `xcontrol' m_PH_* 

* Cubic residualize
foreach var of varlist live_75 `xcontrol' PH_*  {
reg `var' phat phat2 phat3
predict rc_`var', resid
}
reg rc_*
mat bc = e(b)
gen rescub_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_*  {
replace rescub_Y = rescub_Y - bc[1,`counter']*m_`var'
local counter = `counter'+1
}

reg rescub_Y phat phat2 phat3
reg live_75 phat phat2 phat3 `xcontrol' m_PH_* 

* Non-parametric residualize (bw = .05, .075, .1, .15)
* Generate groups by P (to help with computation speed) will give each observation
* the predicted value at the closest rounded p_hat 
gen phat_round = round(phat,.01)
egen Z_group = group(phat_round)
egen id = tag(Z_group)
gen phat_ = phat_round if id==1

* Bandwidth .05
foreach var of varlist live_75 `xcontrol' PH_*  {

lpoly `var' phat, bw(.05) gen(pna_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pna_`var' = mean(pna_`var'_), by(Z_group)
gen rna_`var' = `var'-pna_`var'

di "`var'"
}
reg rna_*
mat bna = e(b)
gen resnona_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_*   {
replace resnona_Y = resnona_Y - bna[1,`counter']*m_`var'
local counter = `counter'+1
}

* Bandwidth .075
foreach var of varlist live_75 `xcontrol'  PH_*  {

lpoly `var' phat, bw(.075) gen(pnb_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pnb_`var' = mean(pnb_`var'_), by(Z_group)
gen rnb_`var' = `var'-pnb_`var'

di "`var'"
}
reg rnb_*
local xcontrol pop1930 frac_radio30 frac_farm30 hhsize30 sq_* cu_* ///
popradio popfarm pophh radiofarm radiohh farmhh cs_1-cs_71
mat bnb = e(b)
gen resnonb_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_* {
replace resnonb_Y = resnonb_Y - bnb[1,`counter']*m_`var'
local counter = `counter'+1
}

* Bandwidth .1
foreach var of varlist live_75 `xcontrol' PH_*  {

lpoly `var' phat, bw(.1) gen(pnc_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pnc_`var' = mean(pnc_`var'_), by(Z_group)
gen rnc_`var' = `var'-pnc_`var'

di "`var'"
}
reg rnc_*
mat bnc = e(b)
gen resnonc_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_* {
replace resnonc_Y = resnonc_Y - bnc[1,`counter']*m_`var'
local counter = `counter'+1
}

* Bandwidth .15
foreach var of varlist live_75 `xcontrol' PH_*  {

lpoly `var' phat, bw(.15) gen(pnd_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pnd_`var' = mean(pnd_`var'_), by(Z_group)
gen rnd_`var' = `var'-pnd_`var'

di "`var'"
}
reg rnd_*
mat bnd = e(b)
gen resnond_Y = live_75
local counter = 1
foreach var of varlist `xcontrol' PH_* {
replace resnond_Y = resnond_Y - bnd[1,`counter']*m_`var'
local counter = `counter'+1
}


* Calculate semi-parametric derivatives
gen U_D = .
gen Y_1 = .
gen Y_0 = .
gen val05 = .
gen mte05 = .
gen val075 = .
gen mte075 = .
gen val1 = .
gen mte1 = .
gen val15 = .
gen mte15 = .
gen valp1 = .
gen mtep1 = .
gen valp2 = .
gen mtep2 = .
gen valp3 = .
gen mtep3 = .

local counter = 1

forvalues x = .36(.005).70 {
replace U_D = `x' in `counter'

reg resnona_Y phat phat2 if inrange(phat,`x'-.05,`x'+.05)
mat b = e(b)
replace val05 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte05 = b[1,1]+2*`x'*b[1,2] in `counter'

reg resnonb_Y phat phat2 if inrange(phat,`x'-.075,`x'+.075)
mat b = e(b)
replace val075 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte075 = b[1,1]+2*`x'*b[1,2] in `counter'

reg resnonc_Y phat phat2 if inrange(phat,`x'-.1,`x'+.1)
mat b = e(b)
replace val1 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte1 = b[1,1]+2*`x'*b[1,2] in `counter'

reg resnond_Y phat phat2 if inrange(phat,`x'-.15,`x'+.15)
mat b = e(b)
replace val15 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte15 = b[1,1]+2*`x'*b[1,2] in `counter'




local counter = `counter' + 1

}

reg reslin_Y phat
mat b = e(b)
replace valp1 = U_D*b[1,1]+b[1,2] if U_D<.
replace mtep1 = b[1,1] if U_D<.

reg resquad_Y phat phat2
mat b = e(b)
replace valp2 = U_D*b[1,1]+U_D^2*b[1,2]+b[1,3] if U_D<.
replace mtep2 = b[1,1]+2*U_D*b[1,2] if U_D<.

reg rescub_Y phat phat2 phat3
mat b = e(b)
replace valp3 = U_D*b[1,1]+U_D^2*b[1,2]+U_D^3*b[1,3]+b[1,4] if U_D<.
replace mtep3 = b[1,1]+2*U_D*b[1,2]+3*U_D^2*b[1,3] if U_D<.

sort U_D
 
 /* Graph to use */

twoway  (scatter mte05 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mte075 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mte1 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mtep1 U_D, connect(l) m(i)) (scatter mtep2 U_D, connect(l) m(i)) (scatter mtep3 U_D, connect(l) m(i))
graph save $output/mte_localiv, replace
 
 
 
 
save $data/dakota_local_iv.dta, replace

log close
