/* Run bootstrap on the parametric MTE by sex */

global data "C:\Users\evanjtaylor\Documents\Dakotas\data"
global dofile "C:\Users\evanjtaylor\Documents\Dakotas\dofile"

/* To run on uchicago server */
*global data "/mnt/fs0/home/evant/Dakotas/data"
*global dofile "/mnt/fs0/home/evant/Dakotas/dofile"



cap log close
log using $dofile/dakota_mte_by_sex.txt, replace text
set seed 12345678

use $data/Dakotas_Mail_Cat.dta, clear


keep if race==1
replace rail_1900 = 0 if rail_1930 == 0
gen rail_new = rail_1930 == 1 & rail_1900 == 0 if rail_1930<.
keep if live_75<. & ornp<. & mail_cat<.


merge m:1 county statefip using $data/newcontrols011018.dta

replace pop1930 = pop1930/1000 /* Made pop1930 in 1000's */

foreach var of varlist pop1930 frac_radio30 frac_farm30 hhsize30 {
gen sq_`var' = `var'^2
gen cu_`var' = `var'^3
}

gen popradio = pop1930*frac_radio30
gen popfarm = pop1930*frac_farm30
gen pophh = pop1930*hhsize30
gen radiofarm = frac_radio30*frac_farm30
gen radiohh = frac_radio30*hhsize30
gen farmhh = frac_farm30*hhsize30


egen cohort_sex = group(birthyr sex born_ND born_SD)
tab cohort_sex, gen(cs_)

local xcontrol pop1930 frac_radio30 frac_farm30 hhsize30 sq_* cu_* ///
popradio popfarm pophh radiofarm radiohh farmhh cs_1-cs_71 



keep ornp mail_cat `xcontrol' live_75 feature_id rail_1900 sex




tempfile all results bootsamp
save `all'

clear
set obs 1
gen int U_D_int = 500
save `results'

forvalues bootdraw = 1/100 {



use `all', clear
bsample, cluster(feature_id)
save `bootsamp', replace

forvalues gender = 1/2 {

/* Logit first stage */
logit ornp i.mail_cat rail_1900 `xcontrol' if sex==`gender'
predict phat_`gender'

qui gen phat2_`gender' = phat_`gender'^2
qui gen phat3_`gender' = phat_`gender'^3 


* De-mean the X variables

foreach var of varlist live_75 `xcontrol' {
sum `var' if sex==`gender'
qui gen m_`gender'_`var' = `var' - r(mean)
}




forvalues j = 0/1 {

qui gen valp2_`gender'_`j' = .
qui gen mtep2_`gender'_`j' = .

* Quadratic residualize
foreach var of varlist live_75 `xcontrol' {
qui reg `var' phat_`gender' phat2_`gender' if ornp==`j' & sex==`gender'
predict rq`j'_`gender'_`var', resid
}
qui reg rq`j'_`gender'_* if ornp==`j' & sex==`gender'
drop rq`j'_*
mat bq = e(b)
qui gen resquad_Y`j'_`gender' = live_75 if ornp==`j' & sex==`gender'
local counter = 1
foreach var of varlist `xcontrol' {
replace resquad_Y`j'_`gender' = resquad_Y`j'_`gender' - bq[1,`counter']*m_`gender'_`var'
local counter = `counter'+1
}

}   /* j loop */

}   /* gender loop */




local counter = 1
qui gen phat_round = round(phat_1,.005) * (sex==1) + round(phat_2,.005) * (sex==2)
sum phat_round
local pmin = r(min)
local pmax = r(max)
qui gen U_D = .

forvalues x = `pmin'(.005)`pmax' {
replace U_D = `x' in `counter'
local counter = `counter' + 1
}

/* Calculate polynomial MTE */
forvalues gender = 1/2 {

qui reg resquad_Y1_`gender' phat_`gender' phat2_`gender' if ornp==1 & sex==`gender'
mat b = e(b)
replace valp2_`gender'_1 = U_D*b[1,1]+U_D^2*b[1,2]+b[1,3] if U_D<.
replace mtep2_`gender'_1 = U_D*(b[1,1]+2*U_D*b[1,2])+valp2_`gender'_1 if U_D<.

qui reg resquad_Y0_`gender' phat_`gender' phat2_`gender' if ornp==0 & sex==`gender'
mat b = e(b)
replace valp2_`gender'_0 = U_D*b[1,1]+U_D^2*b[1,2]+b[1,3] if U_D<.
replace mtep2_`gender'_0 = (U_D-1)*(b[1,1]+2*U_D*b[1,2])+valp2_`gender'_0 if U_D<.

}


foreach ty in "p2_1" "p2_2"  {
qui gen mte`ty' = mte`ty'_1 - mte`ty'_0
}


keep val* mte*  U_D
keep if U_D<.
qui gen int U_D_int = round(U_D * 1000,1)

foreach var of varlist val* mte*  {
rename `var' b`bootdraw'_`var'
}



di `bootdraw'

merge 1:1 U_D_int using `results'
drop _merge
save `results', replace

save $data/dakota_mte_by_sex.dta, replace

} /* bootstrap loop */

save $data/dakota_mte_by_sex.dta, replace
 
 
