/* This do-file does the OLS and IV regression analysis for the Dakotas paper */
/* Tables 4, 5, 8 and 9 */

global data "C:\Users\evanjtaylor\Documents\Dakotas\data"
global dofile "C:\Users\evanjtaylor\Documents\Dakotas\dofile"
global output "C:\Users\evanjtaylor\Documents\Dakotas\output"

cap log close
log using $output\dakota_reg_tables.txt, replace text
set seed 123456789

use $data\Dakotas_Mail_Cat.dta, clear


keep if race==1 & ornp<.
replace rail_1900 = 0 if rail_1930 == 0
gen rail_new = rail_1930 == 1 & rail_1900 == 0 if rail_1930<.

merge m:1 county statefip using $data\newcontrols011018.dta

replace pop1930 = pop1930/1000 /* Made pop1930 in 1000's */

foreach var of varlist pop1930 frac_radio30 frac_farm30 hhsize30 {
gen sq_`var' = `var'^2
gen cu_`var' = `var'^3
}

gen popradio = pop1930*frac_radio30
gen popfarm = pop1930*frac_farm30
gen pophh = pop1930*hhsize30
gen radiofarm = frac_radio30*frac_farm30
gen radiohh = frac_radio30*hhsize30
gen farmhh = frac_farm30*hhsize30


egen cohort_sex = group(birthyr sex born_ND born_SD)
tab cohort_sex, gen(cs_)

local xcontrol pop1930 frac_radio30 frac_farm30 hhsize30 sq_* cu_* ///
popradio popfarm pophh radiofarm radiohh farmhh cs_1-cs_71


sum ornp live_75 if live_75<. & ornp<. & rail_new<.


/* OLS Regressions */
reg live_75 ornp cs_1-cs_71
reg live_75 ornp `xcontrol'
reg live_75 ornp cs_1-cs_72 if rail_new<., cluster(feature_id)
reg live_75 ornp `xcontrol' if rail_new<., cluster(feature_id)  /* Column 1, table 4 */


/* Create Propensity Score using logistic regression */
keep if rail_new<. & live_75<.
logit ornp i.mail_cat rail_new  `xcontrol', cluster(feature_id)
predict phat 



/* IV using 

1. Mail instrument
2. Railroad instrument
3. Both
4. Propensity score  */
/* Table 4, Columns 2-5 */
ivregress 2sls live_75 (ornp = i.mail_cat) `xcontrol', first cluster(feature_id)
reg ornp i.mail_cat `xcontrol', cluster(feature_id)
testparm i.mail_cat

ivregress 2sls live_75 (ornp = rail_1900 rail_new) `xcontrol', first cluster(feature_id)
reg ornp rail_1900 rail_new `xcontrol', cluster(feature_id)
testparm rail_1900 rail_new

ivregress 2sls live_75 (ornp = i.mail_cat rail_1900) `xcontrol', first cluster(feature_id)
reg ornp i.mail_cat  rail_1900 `xcontrol', cluster(feature_id)
testparm i.mail_cat rail_1900 

ivregress 2sls live_75 (ornp = phat) `xcontrol', first cluster(feature_id)


/* IV for small towns */
ivregress 2sls live_75 (ornp = i.mail_cat rail_new) `xcontrol' if pop<6000, first cluster(feature_id)
reg ornp i.mail_cat rail_new `xcontrol' if pop<6000, cluster(feature_id)
testparm i.mail_cat rail_new

/* IV for men and women separately */
/* Table 5 */
ivregress 2sls live_75 (ornp = i.mail_cat rail_new) `xcontrol' if sex==1, first cluster(feature_id)
reg ornp i.mail_cat rail_new `xcontrol' if sex==1, cluster(feature_id)
testparm i.mail_cat rail_new

ivregress 2sls live_75 (ornp = i.mail_cat rail_new) `xcontrol' if sex==2, first cluster(feature_id)
reg ornp i.mail_cat rail_new `xcontrol' if sex==2, cluster(feature_id)
testparm i.mail_cat rail_new



/* IV Regressions Conditional (65 to 70)  */
/* Table 8 */
reg live_70 ornp `xcontrol' if mail_cat<., cluster(feature_id)
ivregress 2sls live_70 (ornp = i.mail_cat) `xcontrol', first cluster(feature_id)
ivregress 2sls live_70 (ornp = rail_1900 rail_new) `xcontrol', first cluster(feature_id)
ivregress 2sls live_70 (ornp = i.mail_cat rail_1900) `xcontrol', first cluster(feature_id)
ivregress 2sls live_70 (ornp = phat) `xcontrol', first cluster(feature_id)

/* IV Regressions (70 to 75) */
/* Table 9 */
reg live_75 ornp `xcontrol' if mail_cat<. & live_70==1, cluster(feature_id)

ivregress 2sls live_75 (ornp = i.mail_cat) `xcontrol' if live_70==1, first cluster(feature_id)
reg ornp i.mail_cat `xcontrol' if live_70==1, cluster(feature_id)
testparm i.mail_cat

ivregress 2sls live_75 (ornp = rail_1900 rail_new) `xcontrol' if live_70==1, first cluster(feature_id)
reg ornp rail_1900 rail_new `xcontrol' if live_70==1, cluster(feature_id)
testparm rail_1900 rail_new

ivregress 2sls live_75 (ornp = i.mail_cat rail_1900) `xcontrol' if live_70==1, first cluster(feature_id)
reg ornp i.mail_cat  rail_1900 `xcontrol' if live_70==1, cluster(feature_id)
testparm i.mail_cat rail_1900 

logit ornp i.mail_cat rail_new `xcontrol' if live_70==1
predict phat70
ivregress 2sls live_75 (ornp = phat70) `xcontrol' if live_70==1, first cluster(feature_id)

log close
