/* Calculates Standard Errors using the Bootstrap draws */
/* Creates Figure 7 */


global data "C:\Users\evanjtaylor\Documents\Dakotas\data"
global dofile "C:\Users\evanjtaylor\Documents\Dakotas\dofile"
global output "C:\Users\evanjtaylor\Documents\Dakotas\output"

/* Get MTE results using Separate Approach */
use $data\dakota_separate.dta, clear
keep U_D mtep2 mte075
keep if U_D<.
gen int U_D_int = round(U_D*1000,1)
tempfile mte
save `mte', replace

/* Get MTE results using Local IV */
use $data\dakota_local_iv.dta, clear
keep U_D mtep2 mte1
rename mte1 liv_mte075 /* This is the semi-par with bw .075 */
rename mtep2 liv_mtep2
keep if U_D<.
gen int U_D_int = round(U_D*1000,1)
tempfile mteliv
save `mteliv', replace

/* Get Bootstrap Draws */
use $data\dakota_bootstrap.dta, clear

merge 1:1 U_D_int using `mte'
drop _merge
merge 1:1 U_D_int using `mteliv'
drop _merge


foreach var in mtep2 liv_mtep2 mte075 liv_mte075 {

egen p5`var' = rowpctile(b?_`var' b??_`var' b???_`var'), p(5)
egen p95`var' = rowpctile(b?_`var' b??_`var' b???_`var'), p(95)
egen sd`var' = rowsd(b?_`var' b??_`var' b???_`var')
egen ct`var' = rownonmiss(b?_`var' b??_`var' b???_`var')

gen p5sd`var' = -1.645 * sd`var' + `var'
gen p95sd`var' = 1.645 * sd`var' + `var'
}

twoway (scatter p5sdliv_mtep2 U_D) (scatter p95sdliv_mtep2 U_D) (scatter liv_mtep2 U_D) if inrange(U_D,.42,.67)
graph save $output/MTE_boot_liv_par.gph, replace
/* Figure 7, Panel A */

twoway (scatter p5sdliv_mte075 U_D) (scatter p95sdliv_mte075 U_D) (scatter liv_mte075 U_D) if inrange(U_D,.42,.67)
graph save $output/MTE_boot_liv_spar.gph, replace
/* Figure 7, Panel B */

twoway (scatter p5sdmtep2 U_D) (scatter p95sdmtep2 U_D) (scatter mtep2 U_D) if inrange(U_D,.42,.67)
graph save $output/MTE_boot_sep_par.gph, replace
/* Figure 7, Panel C */

twoway (scatter p5sdmte075 U_D) (scatter p95sdmte075 U_D) (scatter mte075 U_D) if inrange(U_D,.42,.67)
graph save $output/MTE_boot_sep_spar.gph, replace
/* Figure 7, Panel D */


