/* Generate MTE results using the Separate Approach */
/* Creates Figure 6 */

global data "C:\Users\evanjtaylor\Documents\Dakotas\data"
global dofile "C:\Users\evanjtaylor\Documents\Dakotas\dofile"
global output "C:\Users\evanjtaylor\Documents\Dakotas\output"

cap log close
log using $dofile\dakota_separate.txt, replace text
set seed 123456789

use $data\Dakotas_Mail_Cat.dta, clear


keep if race==1
replace rail_1900 = 0 if rail_1930 == 0
gen rail_new = rail_1930 == 1 & rail_1900 == 0 if rail_1930<.
keep if live_75<. & ornp<. & mail_cat<.

merge m:1 county statefip using $data\newcontrols011018.dta

replace pop1930 = pop1930/1000 /* Made pop1930 in 1000's */

foreach var of varlist pop1930 frac_radio30 frac_farm30 hhsize30 {
gen sq_`var' = `var'^2
gen cu_`var' = `var'^3
}

gen popradio = pop1930*frac_radio30
gen popfarm = pop1930*frac_farm30
gen pophh = pop1930*hhsize30
gen radiofarm = frac_radio30*frac_farm30
gen radiohh = frac_radio30*hhsize30
gen farmhh = frac_farm30*hhsize30


egen cohort_sex = group(birthyr sex born_ND born_SD)
tab cohort_sex, gen(cs_)

local xcontrol pop1930 frac_radio30 frac_farm30 hhsize30 sq_* cu_* ///
popradio popfarm pophh radiofarm radiohh farmhh cs_1-cs_71


/* Semiparametric MTE Estimator */

keep ornp mail_cat `xcontrol' live_75 feature_id birthyr sex born_ND born_SD rail_new rail_1900

local zcontrol i.mail_cat rail_new

/* Logit first stage */
logit ornp `zcontrol' `xcontrol'
predict phat 

gen phat2 = phat^2
gen phat3 = phat^3

xtile cat_phat = phat, n(100)
egen x_phat = mean(phat), by(cat_phat)
egen x_ornp = mean(ornp), by(cat_phat)

* De-mean the X variables

foreach var of varlist live_75 `xcontrol' {
sum `var'
gen m_`var' = `var' - r(mean)
}

gen U_D = .

* Generate for semi-parametric regressions 
gen phat_round = round(phat,.01)
egen Z_group = group(phat_round)
egen id = tag(Z_group)
gen phat_ = phat_round if id==1

forvalues j = 0/1 {

gen val05_`j' = .
gen mte05_`j' = .
gen val075_`j' = .
gen mte075_`j' = .
gen val1_`j' = .
gen mte1_`j' = .
gen val15_`j' = .
gen mte15_`j' = .
gen valp1_`j' = .
gen mtep1_`j' = .
gen valp2_`j' = .
gen mtep2_`j' = .
gen valp3_`j' = .
gen mtep3_`j' = .


* Linear residualize 

foreach var of varlist live_75 `xcontrol' {
reg `var' phat if ornp==`j'
predict rl`j'_`var', resid
}
reg rl`j'_* if ornp==`j'
mat bl = e(b)
gen reslin_Y`j' = live_75 if ornp==`j'
local counter = 1
foreach var of varlist `xcontrol' {
replace reslin_Y`j' = reslin_Y`j' - bl[1,`counter']*m_`var'
local counter = `counter'+1
}

reg reslin_Y`j' phat
reg live_75 phat `xcontrol'
egen x_live75`j' = mean(reslin_Y`j'), by(cat_phat)

* Quadratic residualize
foreach var of varlist live_75 `xcontrol' {
reg `var' phat phat2 if ornp==`j'
predict rq`j'_`var', resid
}
reg rq`j'_* if ornp==`j'
mat bq = e(b)
gen resquad_Y`j' = live_75 if ornp==`j'
local counter = 1
foreach var of varlist `xcontrol' {
replace resquad_Y`j' = resquad_Y`j' - bq[1,`counter']*m_`var'
local counter = `counter'+1
}

foreach var of varlist live_75 `xcontrol' {
reg `var' phat phat2 phat3 if ornp==`j'
predict rc`j'_`var', resid
}
reg rc`j'_* if ornp==`j'
mat bc = e(b)
gen rescub_Y`j' = live_75 if ornp==`j'
local counter = 1
foreach var of varlist `xcontrol' {
replace rescub_Y`j' = rescub_Y`j' - bc[1,`counter']*m_`var'
local counter = `counter'+1
}



* Non-parametric residualize (bw = .05, .075, ,.1 ,.15)
* Generate groups by P (to help with computation speed) will give each observation
* the predicted value at the closest rounded p_hat 


* Bandwidth .05
foreach var of varlist live_75 `xcontrol' {

lpoly `var' phat if ornp==`j', bw(.05) gen(pna`j'_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pna`j'_`var' = mean(pna`j'_`var'_), by(Z_group)
gen rna`j'_`var' = `var'-pna`j'_`var' if ornp==`j'

di "`var'"
}
reg rna`j'_* if ornp==`j'
mat bna = e(b)
gen resnona_Y`j' = live_75
local counter = 1
foreach var of varlist `xcontrol' {
replace resnona_Y`j' = resnona_Y`j' - bna[1,`counter']*m_`var'
local counter = `counter'+1
}

* Bandwidth .075
foreach var of varlist live_75 `xcontrol' {

lpoly `var' phat if ornp==`j', bw(.075) gen(pnb`j'_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pnb`j'_`var' = mean(pnb`j'_`var'_), by(Z_group)
gen rnb`j'_`var' = `var'-pnb`j'_`var' if ornp==`j'

di "`var'"
}
reg rnb`j'_* if ornp==`j'
mat bnb = e(b)
gen resnonb_Y`j' = live_75
local counter = 1
foreach var of varlist `xcontrol' {
replace resnonb_Y`j' = resnonb_Y`j' - bnb[1,`counter']*m_`var'
local counter = `counter'+1
}

* Bandwidth .1
foreach var of varlist live_75 `xcontrol' {

lpoly `var' phat if ornp==`j', bw(.1) gen(pnc`j'_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pnc`j'_`var' = mean(pnc`j'_`var'_), by(Z_group)
gen rnc`j'_`var' = `var'-pnc`j'_`var' if ornp==`j'

di "`var'"
}
reg rnc`j'_* if ornp==`j'
mat bnc = e(b)
gen resnonc_Y`j' = live_75
local counter = 1
foreach var of varlist `xcontrol' {
replace resnonc_Y`j' = resnonc_Y`j' - bnc[1,`counter']*m_`var'
local counter = `counter'+1
}

* Bandwidth .15
foreach var of varlist live_75 `xcontrol' {

lpoly `var' phat if ornp==`j', bw(.15) gen(pnd`j'_`var'_) at(phat_) nogr deg(1) kernel(rec)
egen pnd`j'_`var' = mean(pnd`j'_`var'_), by(Z_group)
gen rnd`j'_`var' = `var'-pnd`j'_`var' if ornp==`j'

di "`var'"
}
reg rnd`j'_* if ornp==`j'
mat bnd = e(b)
gen resnond_Y`j' = live_75
local counter = 1
foreach var of varlist `xcontrol' {
replace resnond_Y`j' = resnond_Y`j' - bnd[1,`counter']*m_`var'
local counter = `counter'+1
}

}

local counter = 1

forvalues x = .36(.005).70 {
replace U_D = `x' in `counter'

reg resnona_Y1 phat phat2 if inrange(phat,`x'-.05,`x'+.05) & ornp==1
mat b = e(b)
replace val05_1 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte05_1 = 2*`x'*b[1,1]+3*`x'^2*b[1,2]+b[1,3] in `counter'

reg resnona_Y0 phat phat2 if inrange(phat,`x'-.05,`x'+.05) & ornp==0
mat b = e(b)
replace val05_0 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte05_0 = val05_0 + (`x'-1)*(b[1,1]+2*`x'*b[1,2]) in `counter'


reg resnonb_Y1 phat phat2 if inrange(phat,`x'-.075,`x'+.075) & ornp==1
mat b = e(b)
replace val075_1 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte075_1 = 2*`x'*b[1,1]+3*`x'^2*b[1,2]+b[1,3] in `counter'

reg resnonb_Y0 phat phat2 if inrange(phat,`x'-.075,`x'+.075) & ornp==0
mat b = e(b)
replace val075_0 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte075_0 = val075_0 + (`x'-1)*(b[1,1]+2*`x'*b[1,2]) in `counter'


reg resnonc_Y1 phat phat2 if inrange(phat,`x'-.1,`x'+.1) & ornp==1
mat b = e(b)
replace val1_1 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte1_1 = 2*`x'*b[1,1]+3*`x'^2*b[1,2]+b[1,3] in `counter'

reg resnonc_Y0 phat phat2 if inrange(phat,`x'-.1,`x'+.1) & ornp==0
mat b = e(b)
replace val1_0 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte1_0 = val1_0 + (`x'-1)*(b[1,1]+2*`x'*b[1,2]) in `counter'


reg resnond_Y1 phat phat2 if inrange(phat,`x'-.15,`x'+.15) & ornp==1
mat b = e(b)
replace val15_1 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte15_1 = 2*`x'*b[1,1]+3*`x'^2*b[1,2]+b[1,3] in `counter'

reg resnond_Y0 phat phat2 if inrange(phat,`x'-.15,`x'+.15) & ornp==0
mat b = e(b)
replace val15_0 = `x'*b[1,1]+`x'^2*b[1,2]+b[1,3] in `counter'
replace mte15_0 = val15_0 + (`x'-1)*(b[1,1]+2*`x'*b[1,2]) in `counter'



local counter = `counter' + 1

}

/* Calculate polynomial MTE */

reg reslin_Y1 phat if ornp==1
mat b = e(b)
replace valp1_1 = U_D*b[1,1]+b[1,2] if U_D<.
replace mtep1_1 = U_D*b[1,1]+valp1_1 if U_D<.

reg reslin_Y0 phat if ornp==0
mat b = e(b)
replace valp1_0 = U_D*b[1,1]+b[1,2] if U_D<.
replace mtep1_0 = (U_D-1)*b[1,1]+valp1_0 if U_D<.

reg resquad_Y1 phat phat2 if ornp==1
mat b = e(b)
replace valp2_1 = U_D*b[1,1]+U_D^2*b[1,2]+b[1,3] if U_D<.
replace mtep2_1 = U_D*(b[1,1]+2*U_D*b[1,2])+valp2_1 if U_D<.

reg resquad_Y0 phat phat2 if ornp==0
mat b = e(b)
replace valp2_0 = U_D*b[1,1]+U_D^2*b[1,2]+b[1,3] if U_D<.
replace mtep2_0 = (U_D-1)*(b[1,1]+2*U_D*b[1,2])+valp2_0 if U_D<.

reg rescub_Y1 phat phat2 phat3 if ornp==1
mat b = e(b)
replace valp3_1 = U_D*b[1,1]+U_D^2*b[1,2]+U_D^3*b[1,3]+b[1,4] if U_D<.
replace mtep3_1 = U_D*(b[1,1]+2*U_D*b[1,2]+3*U_D^2*b[1,3])+valp3_1 if U_D<.

reg rescub_Y0 phat phat2 phat3 if ornp==0
mat b = e(b)
replace valp3_0 = U_D*b[1,1]+U_D^2*b[1,2]+U_D^3*b[1,3]+b[1,4] if U_D<.
replace mtep3_0 = (U_D-1)*(b[1,1]+2*U_D*b[1,2]+3*U_D^2*b[1,3])+valp3_0 if U_D<.


foreach ty in "p1" "p2" "p3" "05" "075" "1" "15" {
gen mte`ty' = mte`ty'_1 - mte`ty'_0
}

sort U_D


twoway  (scatter mte05 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mte075 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mte1 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mtep1 U_D, connect(l) m(i)) (scatter mtep2 U_D, connect(l) m(i)) ///
(scatter mtep3 U_D, connect(l) m(i)) 
graph save $output/mte_sep, replace
/* Figure 6 */


/* Other figures not included in paper */
twoway  (scatter mte05_1 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mte075_1 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mte1_1 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mtep1_1 U_D, connect(l) m(i)) (scatter mtep2_1 U_D, connect(l) m(i)) 
graph save $output/y1_sep, replace

twoway  (scatter mte05_0 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mte075_0 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mte1_0 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter mtep1_0 U_D, connect(l) m(i)) (scatter mtep2_0 U_D, connect(l) m(i)) 
graph save $output/y0_sep, replace

twoway  (scatter val05_0 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter val075_0 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter val1_0 U_D if inrange(U_D,.42,.67), connect(l) m(i))  ///
(scatter valp1_0 U_D, connect(l) m(i)) (scatter valp2_0 U_D, connect(l) m(i)) 
graph save $output/val0_sep, replace

twoway  (scatter mtep2_1 U_D, connect(l) m(i)) (scatter mtep2_0 U_D, connect(l) m(i)) ///
(scatter valp2_1 U_D, connect(l) m(i)) (scatter valp2_0 U_D, connect(l) m(i)) 
graph save $output/bounds_sep, replace

save $data/dakota_separate.dta, replace

log close



