clear *
cap log close
set mem 70m
set more off
cd "C:\Users\jannaj\Dropbox\Migration\Oct2018"
# delimit ;

/*****************************************************************
This file produces Figure 2 in the paper.

The source data can be downloaded from IPUMS-USA and is detailed
in fig2data.cbk
*****************************************************************/;

use fig2data;


*Fix missing birth year;
replace birthyr=year-age if birthyr==0;

*keep only birth cohorts 1916-1927;
keep if birthyr>=1916 & birthyr<=1927;

*keep right bpl;
keep if bpl==30 | bpl==38 | bpl==46;

*Define in RNP (outside birth state)/not in RNP;
/******************
Rural Northern Plains
(MT(30), ND(38), SD(46))
Rural MN(below) (outside MSP(512))
IA (19)
NE (31)
WY (56)
ID (16)
*******************/;
*rural MN;
gen msp = metarea==512;
replace msp = 1 if statefip==27 & metro>1 & (year==1960 | year==1970);
tab year msp, row;
gen ruralmn = msp==0 & statefip==27;
tab year ruralmn;

*stay in birth state;
gen inbstate = 0;
foreach state in 30 38 46 {;
replace inbstate = 1 if bpl==`state' & statefip==`state';
};
tab year inbstate;

*stay in RNP;
gen inrnp = 0;
replace inrnp=1 if bpl==30 & (statefip==38 | statefip==46 | ruralmn==1 | statefip==19 | statefip==31 | statefip==56 | statefip==16);
replace inrnp=1 if bpl==38 & (statefip==30 | statefip==46 | ruralmn==1 | statefip==19 | statefip==31 | statefip==56 | statefip==16);
replace inrnp=1 if bpl==46 & (statefip==30 | statefip==38 | ruralmn==1 | statefip==19 | statefip==31 | statefip==56 | statefip==16);
tab year inrnp;

*outside RNP;
gen outrnp = 1;
replace outrnp=0 if inbstate==1;
replace outrnp=0 if inrnp==1;
tab year outrnp;
save fig2data_clean, replace;  

*collapse to graph dataset;
collapse (mean) inbstate inrnp outrnp (sum) n_inb = inbstate n_inrnp = inrnp n_outrnp = outrnp [aw=perwt], by(age);

*make graph;

graph twoway scatter inrnp age || scatter outrnp age, 
legend(label(1 "Non-migrant, outside birth state") label(2 "Migrant") order(2 1)) 
ytitle("Fraction") xtitle("Age") scheme(s1mono);

