clear *
cap log close
set more off
cd "C:\Users\jannaj\Dropbox\Migration\Oct2018"
log using table10.log, text replace
#delimit ;

/******************************
This file generates the dissimilarity
of cause of death results shown in 
Table 10 of the paper.

The raw source data is the NCHS
Vital Statistics Multiple Cause
of Death files for 1982-2001,
available online from the CDC
or NBER.  In the following code,
these files are named 
"mort`year'.dta"
********************************/

use mort1982;

gen year = 1982;

*keep needed variables;
keep year stateoc countyrs staters cityrs popsize metro monthdth daydth sex race age statebth fipsctyr fipsstr fipssmsa ucr72 ucr34;

/* 1982 only has 50% of multiple cause data coded for following states:
1	Alabama
3	Arizona
4	Arkansas
5	California
10	Florida
11 	Georgia
13	Idaho
14 	Illinois
15	Indiana
18 	Kentucky
27	Montana
35 	North Dakota
36	Ohio
37	Oklahoma
40	Rhode Island
43	Tennessee
44	Texas
48	Washington
49	West Virginia
so need to create "weight" for deaths occurring in these states */;

destring stateoc, replace;

gen weight = 1;
foreach state in 1	3	4	5	10	11 	13	14 	15	18 	27	35 	36	37	40	43	44	48	49	{;
replace weight=2 if stateoc==`state';
};

*Keep only those born in Dakotas and Montana;
keep if statebth==27 | statebth==35 | statebth==42;

*Drop babies;
drop if age>200;

*Birth Cohort;
gen cohort = 1982-age;

*Keep only cohorts of interest;
keep if cohort>=1916 & cohort<=1927;

tab age;

*Keep only whites;
keep if race==1;

*Migrants vs. non-migrants;
/* Non-migrants live in:
North Dakota
South Dakota   
Montana
Idaho
Wyoming
Outstate Minnesota
Iowa
Nebraska */;


gen migrant=1;
replace migrant=0 if fipsstr==16 | fipsstr==19 | fipsstr==30 | fipsstr==31 | fipsstr==38 | fipsstr==46 | fipsstr==56;
replace migrant=0 if fipsstr==27 & fipssmsa!=5120;
tab migrant;

save cause1982, replace;

clear;

forvalues year = 1983(1)1989 {;
use mort`year';
gen year = `year';
tab year;
*keep needed variables;
keep year stateoc countyrs staters cityrs popsize metro monthdth /* daydth */ sex race age statebth fipsctyr fipsstr fipssmsa ucr72 ucr34;
destring stateoc, replace;
*Keep only those born in Dakotas and Montana;
keep if statebth==27 | statebth==35 | statebth==42;

*Drop babies;
drop if age>200;

*Birth Cohort;
gen cohort = `year'-age;

*Keep only cohorts of interest;
keep if cohort>=1916 & cohort<=1927;

tab age;

*Keep only whites;
tab race;
keep if race==1;

*Migrants vs. non-migrants;
/* Non-migrants live in:
North Dakota
South Dakota   
Montana
Idaho
Wyoming
Outstate Minnesota
Iowa
Nebraska */;


gen migrant=1;
replace migrant=0 if fipsstr==16 | fipsstr==19 | fipsstr==30 | fipsstr==31 | fipsstr==38 | fipsstr==46 | fipsstr==56;
replace migrant=0 if fipsstr==27 & fipssmsa!=5120;
tab migrant;

save cause`year', replace;
clear;
};

forvalues year = 1990(1)1995 {;
use ~/migration/mort/mort_data/mort`year';
cap drop year;
gen year = `year';
tab year;
*keep needed variables;
keep year stateoc countyrs staters cityrs popsize metro monthdth sex race age statebth fipsctyr fipsstr fipspmsa ucr72 ucr34;
destring stateoc, replace;
*Keep only those born in Dakotas and Montana;
keep if statebth==27 | statebth==35 | statebth==42;

*Drop babies;
drop if age>200;

*Birth Cohort;
gen cohort = `year'-age;

*Keep only cohorts of interest;
keep if cohort>=1916 & cohort<=1927;

tab age;

*Keep only whites;
tab race;
keep if race==1;

*Migrants vs. non-migrants;
/* Non-migrants live in:
North Dakota
South Dakota   
Montana
Idaho
Wyoming
Outstate Minnesota
Iowa
Nebraska */;


gen migrant=1;
replace migrant=0 if fipsstr==16 | fipsstr==19 | fipsstr==30 |  fipsstr==31 | fipsstr==38 | fipsstr==46 | fipsstr==56;
replace migrant=0 if fipsstr==27 & fipspmsa!=5120;
tab migrant;

save cause`year', replace;
clear;
};

forvalues year = 1996(1)1998 {;
use ~/migration/mort/mort_data/mort`year';
cap drop year;
gen year = `year';
tab year;
*keep needed variables;
keep year stateoc countyrs staters cityrs popsize metro monthdth sex race age statbth fipsctyr fipsstr fipspmsa ucr72 ucr34;
destring stateoc, replace;
*Keep only those born in Dakotas and Montana;
keep if statbth==27 | statbth==35 | statbth==42;

*Drop babies;
drop if age>200;

*Birth Cohort;
gen cohort = `year'-age;

*Keep only cohorts of interest;
keep if cohort>=1916 & cohort<=1927;

tab age;

*Keep only whites;
tab race;
keep if race==1;

*Migrants vs. non-migrants;
/* Non-migrants live in:
North Dakota
South Dakota   
Montana
Idaho
Wyoming
Outstate Minnesota
Iowa
Nebraska */;


gen migrant=1;
replace migrant=0 if fipsstr==16 | fipsstr==19 | fipsstr==30 | fipsstr==31 | fipsstr==38 | fipsstr==46 | fipsstr==56;
replace migrant=0 if fipsstr==27 & fipspmsa!=5120;
tab migrant;

save cause`year', replace;
clear;
};

forvalues year = 1999(1)2001 {;
use ~/migration/mort/mort_data/mort`year';
cap drop year;
gen year = `year';
tab year;
*keep needed variables;
keep year stateoc countyrs staters cityrs popsize metro monthdth sex race age statbth fipsctyr fipsstr fipspmsa ucr39;
destring stateoc, replace;
*Keep only those born in Dakotas and Montana;
keep if statbth==27 | statbth==35 | statbth==42;

*Drop babies;
drop if age>200;

*Birth Cohort;
gen cohort = `year'-age;

*Keep only cohorts of interest;
keep if cohort>=1916 & cohort<=1927;

tab age;

*Keep only whites;
tab race;
keep if race==1;

*Migrants vs. non-migrants;
/* Non-migrants live in:
North Dakota
South Dakota   
Montana
Idaho
Wyoming
Outstate Minnesota
Iowa
Nebraska */;


gen migrant=1;
replace migrant=0 if fipsstr==16 | fipsstr==19 | fipsstr==30 | fipsstr==31 | fipsstr==38 | fipsstr==46 | fipsstr==56;
replace migrant=0 if fipsstr==27 & fipspmsa!=5120;
tab migrant;

save cause`year', replace;
clear;
};

/* Append them all */;
use cause1982;
forval year = 1983(1)2001 {;
append using cause`year';
};
save causeraw, replace;

/* Get cause of death codes to line up decently - there was a change in the UCR codes during the time period */;

gen ucr=.;
replace ucr = 1 if ucr34==10 | ucr39==1;
replace ucr = 2 if ucr34==20 | ucr39==2;

replace ucr = 3 if ucr34==50 | ucr39==5 | ucr39==6 | ucr39==7;
replace ucr = 4 if ucr34==60 | ucr39==8;
replace ucr = 5 if ucr34==70 | ucr39==9;
replace ucr = 6 if ucr34==80 | ucr39==10 | ucr39==11;
replace ucr = 7 if ucr34==90 | ucr39==12;
replace ucr = 8 if ucr34==100 | ucr39==14;
replace ucr = 9 if ucr34==110 | ucr39==15 | ucr39==13;

replace ucr = 10 if ucr34==120 | ucr39==16;

replace ucr = 11 if ucr34==160 | ucr39==20;
replace ucr = 12 if ucr34==170 | ucr39==21;
replace ucr = 13 if ucr34==180 | ucr34==150 | ucr39==22;
replace ucr = 14 if ucr34==190 | ucr39==23;
replace ucr = 15 if ucr34==200 | ucr39==24;
replace ucr = 16 if ucr34==210 | ucr39==25;
replace ucr = 17 if ucr34==220 | ucr39==26;

replace ucr = 18 if ucr34==230 | ucr39==27;
replace ucr = 19 if ucr34==240 | ucr39==28;
replace ucr = 20 if ucr34==250 | ucr39==29;
replace ucr = 21 if ucr34==260 | ucr39==30;
replace ucr = 22 if ucr34==270 | ucr39==31;
replace ucr = 23 if ucr34==280 | ucr39==32;
replace ucr = 24 if ucr34==300 | ucr39==33;
replace ucr = 25 if ucr34==290 | ucr39==34;
replace ucr = 26 if ucr34==310 | ucr39==35 | ucr39==36;
replace ucr = 27 if ucr34==320 | ucr34==30 | ucr39==37 | ucr39==17;

replace ucr = 28 if ucr34==330 | ucr39==38;
replace ucr = 29 if ucr34==340 | ucr39==39;
replace ucr = 30 if ucr34==350 | ucr39==40;
replace ucr = 31 if ucr34==360 | ucr39==41;
replace ucr = 32 if ucr34==370 | ucr39==42;

replace weight=1 if weight==.;

*labelling stuff;

label variable ucr "Cause of death";
label def ucr
1	"Tuberculosis"
2	"Syphilis"
	
3	"Cancer - Digestive System"
4	"Cancer - Lung and Thorax"
5	"Cancer - Breast"
6	"Cancer - Genital"
7	"Cancer - Urinary"
8	"Leukemia"
9	"Cancer - Other"
	
10	"Diabetes"
	
11	"Hypertensive heart disease"
12	"Heart attack"
13	"Other heart disease"
14	"Hypertension" 
15	"Stroke"
16	"Atherosclerosis"
17	"Other circulatory diseases"
	
18	"Pneumonia/influenza"
19	"Emphysema"
20	"Ulcer"
21	"Cirrhosis and liver disease"
22	"Kidney disease"
23	"Pregnancy"
24	"Birth trauma (infant)"
25	"Congenital anomalies"
26	"Ill-defined conditions"
27	"All other diseases"  
	
28	"Motor vehicle accidents"
29	"Other accident"
30	"Suicide"
31	"Homicide"
32	"All other external causes";
label val ucr ucr;
compress;

save causedata, replace;

/************************************ Compute dissimilarity of cause of death *****************************/
clear;
use causedata;
keep if age>=65 & age<=74;
gen newcod = .;

replace newcod = 1 if ucr39==1 | ucr34==10;
replace newcod = 2 if ucr39==2 | ucr34==20;
replace newcod = 3 if ucr39==5 | ucr39==6 | ucr39==7 | ucr34==50;
replace newcod = 4 if ucr39==8 | ucr34==60;
replace newcod = 5 if ucr39==9 | ucr34==70;
replace newcod = 6 if ucr39==10 | ucr39==11 | ucr34==80;
replace newcod = 7 if ucr39==12 | ucr34==90;
replace newcod = 8 if ucr39==14 | ucr34==100;
replace newcod = 9 if ucr39==13 | ucr39==15 | ucr34==110;
replace newcod = 10 if ucr39==16 | ucr34==120;
replace newcod = 11 if ucr39==20 | ucr39==21 | ucr39==22 | ucr39==23 | ucr39==24 | ucr39==25 | ucr39==26 | ucr34==150 
| ucr34==160 | ucr34==170 | ucr34==180 | ucr34==190 | ucr34==200 | ucr34==210 | ucr34==220;
replace newcod = 12 if ucr39==27 | ucr34==230;
replace newcod = 13 if ucr39==28 | ucr34==240;
replace newcod = 14 if ucr39==29 | ucr34==250;
replace newcod = 15 if ucr39==30 | ucr34==260;
replace newcod = 16 if ucr39==31 | ucr34==270;
replace newcod = 17 if ucr39==32 | ucr34==280;
replace newcod = 18 if ucr39==33 | ucr34==300;
replace newcod = 19 if ucr39==34 | ucr34==290;
replace newcod = 20 if ucr39==36 | ucr39==35 | ucr34==310;
replace newcod = 21 if ucr39==3 | ucr39==17 | ucr39==37 | ucr34==30 | ucr34==320;
replace newcod = 22 if ucr39==38 | ucr34==330;
replace newcod = 23 if ucr39==39 | ucr34==340;
replace newcod = 24 if ucr39==40 | ucr34==350;
replace newcod = 25 if ucr39==41 | ucr34==360;
replace newcod = 26 if ucr39==42 | ucr34==370;

save newcausedata, replace;

/* First compute total deaths among migrants and nonmigrants by cause of death */;
gen n=1;

collapse (sum) deaths = weight, by(newcod sex migrant);

egen totdeaths = total(deaths), by(sex migrant);

/* proportion of deaths */;

gen deathprop = deaths/totdeaths;

reshape wide deathprop deaths totdeaths, i(sex newcod) j(migrant);

gen dissim = deathprop1/deathprop0;

gsort sex -dissim;

label variable newcod " Combined cause of death";
label def newcod

1	"Tuberculosis"
2	"Syphilis"
3	"Cancer: stomach, colon, pancreas, peritoneum"
4	"Cancer: resipiratory and intrathoracic organs"
5	"Cancer: breast"
6	"Cancer: genital organs"
7	"Cancer: urinary organs"
8	"Cancer: leukemia"
9	"Cancer: other"
10	"Diabetes mellitus"
11	"Major cardiovascular diseases"
12	"Pneumonia and influenza"
13	"Chronic obstructive pulmonary diseases"
14	"Ulcer of stomach and duodenum"
15	"Chronic liver disease and cirrhosis"
16	"Nephritis, nephrotic syndrome, and nephrosis"
17	"Pregnancy, childbirth, and the puerperium"
18	"Certain conditions originating in the perinatal period"
19	"Congenital malformations, deformations and chromosomal abnormalities"
20	"Symptoms, signs, and ill-defined conditions"
21	"All other diseases and internal causes"
22	"Motor vehicle accidents"
23	"All other and unspecified accidents and adverse effects"
24	"Intentional self-harm (suicide)"
25	"Assault (homicide)"
26	"All other external causes";

label val newcod newcod;
compress;

list newcod dissim deaths0 deaths1 if sex==1, clean noobs;

list newcod dissim deaths0 deaths1 if sex==2, clean noobs;

clear;
use newcausedata;
keep sex migrant newcod weight;
# delimit cr

expand weight
drop weight
tempfile data
save `data'

tab newcod, gen(cod)
tab newcod if sex==1
tab newcod if sex==2
collapse (mean) cod*, by(sex migrant)
foreach var of varlist cod* {
rename `var' `var'_
}

reshape wide cod*, i(sex) j(migrant)

forvalues x = 1/23 {
gen rat_`x' = cod`x'_1 / cod`x'_0
}

bysort sex: sum rat*

set seed 12345678
local reps 1000
forvalues x = 1/`reps' {

use `data', clear
bsample, str(sex migrant)

quietly tab newcod, gen(cod)

collapse (mean) cod*, by(sex migrant)

gen rep = `x'

tempfile results`x'
save `results`x'', replace

}

use `results1', clear
forvalues x = 2/`reps' {
append using `results`x''
}

foreach var of varlist cod* {
rename `var' `var'_
}

reshape wide cod*, i(sex rep) j(migrant)

forvalues x = 1/23 {
gen rat_`x' = cod`x'_1 / cod`x'_0
}

bysort sex: sum rat*

save table10results, replace








