clear *
cap log close
set more off
cd "C:\Users\jannaj\Dropbox\Migration\Oct2018"
log using table2.log, text replace
# delimit ;

/*****************************************************************
This file produces the earnings difference results shown in Table 2
of the paper.

The raw data comes from IPUMS-USA and is detailed in table2data.cbk
*****************************************************************/;

use table2data;

*keep state 1970 data;
drop if datanum>2;

*keep only birth cohorts 1916-1927;
keep if birthyr>=1916 & birthyr<=1927;

*keep only NH white;
drop if race>1;
drop if hispan>0;

*Define in RNP (outside birth state)/not in RNP;
/******************
Rural Northern Plains
(MT(30), ND(38), SD(46))
Rural MN(below) (outside MSP(512))
IA (19)
NE (31)
WY (56)
ID (16)
*******************/;

*rural MN;
gen msp = metarea==512;
replace msp = 1 if statefip==27 & metro>1 & (year==1960 | year==1970);
tab year msp, row;
gen ruralmn = msp==0 & statefip==27;
tab year ruralmn, row;

*stay in birth state;
gen inbstate = 0;
foreach state in 30 38 46 {;
replace inbstate = 1 if bpl==`state' & statefip==`state';
};
tab year inbstate, row;

*stay in RNP;
gen inrnp = 0;
replace inrnp=1 if bpl==30 & (statefip==38 | statefip==46 | ruralmn==1 | statefip==19 | statefip==31 | statefip==56 | statefip==16);
replace inrnp=1 if bpl==38 & (statefip==30 | statefip==46 | ruralmn==1 | statefip==19 | statefip==31 | statefip==56 | statefip==16);
replace inrnp=1 if bpl==46 & (statefip==30 | statefip==38 | ruralmn==1 | statefip==19 | statefip==31 | statefip==56 | statefip==16);
tab year inrnp, row;

*outside RNP;
gen ornp = 1;
replace ornp=0 if inbstate==1;
replace ornp=0 if inrnp==1;
tab year ornp, row;


/********************* EARNINGS DIFFERENCES (men, 1960, 1970, 1980)**********************/;
keep if sex==1;
*recode income missings & create log wage;
recode incwage 999999=.;
gen lnwage = ln(incwage);

*create education categories;
gen grade8 = educ<=2;
gen lths = (educ>=3 & educ<=5);
gen hsgrad = educ==6;
gen somecol = (educ>=7 & educ<=9);
gen colgradplus = educ>=10;

gen rnp = (inbstate==1 | inrnp==1);
tab ornp rnp;

*In LF indicator;
gen inlf=.;
replace inlf=0 if labforce==1;
replace inlf=1 if labforce==2;
tab year inlf;


foreach year in 1960 1970 1980 {;
	egen group = group(age grade8 lths hsgrad somecol colgradplus) if year==`year' & inlf==1;
	egen n_ornp = total(ornp) if year==`year', by(group);
	egen n_rnp = total(rnp) if year==`year', by(group);
	gen p_migrate = n_ornp/(n_ornp+n_rnp) if year==`year';
	
	di "ATE `year'"; 
	gen atewt = perwt/(1-p_migrate) if ornp == 0 & year == `year' & p_migrate>0;
	replace atewt = perwt/p_migrate if ornp==1 & year==`year' & p_migrate<1;
	reg lnwage ornp lths hsgrad somecol colgradplus i.age [aw=atewt] if inlf==1;
	
	drop n_ornp n_rnp p_migrate atewt group;
	};
