clear *
cap log close
set more off
cd "C:\Users\jannaj\Dropbox\Migration\Oct2018"
log using table7.log, text replace
# delimit ;

/***********************************************************
This program replicates Table 7

The source mortality data is the Multiple Cause of Death 
Data from NCHS, I downloaded it from the NBER website.

The source population data is from IPUMS-USA 
***********************************************************/;


/***********************  DEATHS  ***************************/;

forval year = 1959(1)1959 {;
use mort`year';

*keep right states of birth;
keep if stbirth==27 | stbirth==35 | stbirth==42;
gen bpl=.;
replace bpl=30 if stbirth==27;
replace bpl=38 if stbirth==35;
replace bpl=46 if stbirth==42;

*keep whites only;
keep if race==1;

*keep only needed variables;
keep monthdth staters metro smsares sex age stbirth bpl;

gen n=1;
gen birthyr = `year'-age;
destring staters, replace;
destring metro, replace;

*ornp;
gen ornp=1;
replace ornp=0 if staters==13 /* ID */ | staters==16 /* IA */ | (staters==24 & metro==3) /* MN */ | staters==27 /* MT */ | 
staters==28 /* NE */ |staters==35 /* ND */ | staters==42 /* SD */ | staters==51 /* WY */; 

gen year = `year';
save deaths_`year'_raw, replace;
clear;
};

forval year = 1960(1)1963 {;
use mort`year';

*keep right states of birth;
keep if stbirth==27 | stbirth==35 | stbirth==42;
gen bpl=.;
replace bpl=30 if stbirth==27;
replace bpl=38 if stbirth==35;
replace bpl=46 if stbirth==42;

*keep whites only;
keep if race==1;

*keep only needed variables;
keep monthdth staters metro smsares sex age stbirth bpl;

gen n=1;
gen birthyr = `year'-age;
destring staters, replace;
destring metro, replace;

*ornp;
gen ornp=1;
replace ornp=0 if staters==13 /* ID */ | staters==16 /* IA */ | (staters==24 & metro==2) /* MN */ | staters==27 /* MT */ | 
staters==28 /* NE */ |staters==35 /* ND */ | staters==42 /* SD */ | staters==51 /* WY */; 

gen year = `year';
save deaths_`year'_raw, replace;
clear;
};

use deaths_1959_raw;
forval year = 1960(1)1963 {;
	append using deaths_`year'_raw;
	};
	
gen censusyear = year;
replace censusyear = year-1 if monthdth<4;

collapse (sum) deaths = n, by(sex birthyr ornp censusyear bpl);

keep if birthyr>=1916 & birthyr<=1927;
keep if censusyear>=1959 & censusyear<=1962;

reshape wide deaths, i(sex birthyr ornp bpl) j(censusyear);
sum;

save deaths60s, replace;

/***************************   POPULATION   *************************/;

/* Census data */;
use  table7popdata;

keep if year==1960;
keep if birthyr>=1916 & birthyr<=1927;

*whites only;
keep if race==1;
keep if hispan==0;

*ornp;
gen ornp=1;
replace ornp=0 if statefip==19 | statefip==16 | (statefip==27 & metro>1) | statefip==30 | statefip==31 |statefip==38 |
 statefip==46 | statefip==56; 

collapse (sum) pop1960 = perwt, by(sex birthyr ornp bpl);

/******************  MERGE DEATHS TO POPULATION *************************/

merge 1:1 sex birthyr ornp bpl using deaths60s;
replace deaths1960 = 0 if deaths1960==.;
replace deaths1961 = 0 if deaths1961==.;
replace deaths1962 = 0 if deaths1962==.;
drop _merge;

* use forward estimator for 1961, 1962 populations, backward for 1959;
gen pop1959 = pop1960+deaths1960;
gen pop1961 = pop1960-deaths1960;
gen pop1962 = pop1961-deaths1961;

reshape long pop deaths, i(sex birthyr ornp bpl) j(censusyear);

gen personyears = round(pop - (deaths/2));

gen deathrate = deaths/personyears;
gen survrate = 1-deathrate;
bysort censusyear: table birthyr ornp if sex==1, contents(mean deathrate);
bysort censusyear: table birthyr ornp if sex==2, contents(mean deathrate);

save deathrate60s, replace;

collapse (sum) personyears deaths, by(sex ornp censusyear);
gen deathrate = deaths/personyears;

bysort censusyear: tab ornp if sex==1, sum(deathrate);
bysort censusyear: tab ornp if sex==2, sum(deathrate);

collapse (sum) personyears deaths, by(sex ornp);
gen deathrate = deaths/personyears;
gen survrate = 1 - deathrate;
tab ornp if sex==1, sum(deathrate);
tab ornp if sex==2, sum(deathrate);

tab ornp if sex==1, sum(survrate);
tab ornp if sex==2, sum(survrate);
clear;

/*************************  1980 - 1992  **************************/;

/***********************  DEATHS  ***************************/;
/*
forval year = 1980(1)1993 {;
use "../../Undercounts update/data/mort`year'";

*keep right states of birth;
keep if statebth==27 | statebth==35 | statebth==42;
gen bpl=.;
replace bpl=30 if statebth==27;
replace bpl=38 if statebth==35;
replace bpl=46 if statebth==42;

*keep whites only;
keep if race==1;

*keep only needed variables;
keep monthdth staters metro sex age statebth bpl;

gen n=1;
gen birthyr = `year'-age;
destring staters, replace;
destring metro, replace;

*ornp;
gen ornp=1;
replace ornp=0 if staters==13 /* ID */ | staters==16 /* IA */ | (staters==24 & metro=="2") /* MN */ | staters==27 /* MT */ | 
staters==28 /* NE */ |staters==35 /* ND */ | staters==42 /* SD */ | staters==51 /* WY */; 

gen year = `year';
save deaths_`year'_raw, replace;
clear;
};


use deaths_1980_raw;
forval year = 1981(1)1993 {;
	append using deaths_`year'_raw;
	};
	
gen censusyear = year;
replace censusyear = year-1 if monthdth<4;

collapse (sum) deaths = n, by(sex birthyr ornp bpl censusyear);

keep if birthyr>=1916 & birthyr<=1927;
keep if censusyear>=1980 & censusyear<=1992;

reshape wide deaths, i(sex birthyr ornp bpl) j(censusyear);
sum;

save deaths80s, replace;
*/
/***************************   POPULATION   *************************/;

/* Census data */;
use  table7popdata;

keep if year==1980 | year==1990;
keep if birthyr>=1916 & birthyr<=1927;

rename year censusyear;

*whites only;
keep if race==1;
keep if hispan==0;


*ornp;
gen ornp=1;
replace ornp=0 if statefip==19 | statefip==16 | (statefip==27 & metarea!=512) | statefip==30 | statefip==31 |statefip==38 |
 statefip==46 | statefip==56; 

 tab censusyear ornp;

collapse (sum) pop = perwt, by(sex birthyr ornp censusyear bpl);

keep if birthyr>=1916 & birthyr<=1927;

reshape wide pop, i(sex birthyr ornp bpl) j(censusyear);

merge 1:1 sex birthyr ornp bpl using deaths80s;
*replace deaths = 0 if deaths==.;
drop _merge;

* use minimum distance estimator for 1981-1989, forward estimator for 1991 & 1992;
gen pop1981 = ((pop1980-deaths1980) + (pop1990+deaths1989+deaths1988+deaths1987+deaths1986+deaths1985+deaths1984+deaths1983+deaths1982+deaths1981))/2;
gen pop1982 = ((pop1980-deaths1980-deaths1981) + (pop1990+deaths1989+deaths1988+deaths1987+deaths1986+deaths1985+deaths1984+deaths1983+deaths1982))/2;
gen pop1983 = ((pop1980-deaths1980-deaths1981-deaths1982) + (pop1990+deaths1989+deaths1988+deaths1987+deaths1986+deaths1985+deaths1984+deaths1983))/2;
gen pop1984 = ((pop1980-deaths1980-deaths1981-deaths1982-deaths1983) + (pop1990+deaths1989+deaths1988+deaths1987+deaths1986+deaths1985+deaths1984))/2;
gen pop1985 = ((pop1980-deaths1980-deaths1981-deaths1982-deaths1983-deaths1984) + (pop1990+deaths1989+deaths1988+deaths1987+deaths1986+deaths1985))/2;
gen pop1986 = ((pop1980-deaths1980-deaths1981-deaths1982-deaths1983-deaths1984-deaths1985) + (pop1990+deaths1989+deaths1988+deaths1987+deaths1986))/2;
gen pop1987 = ((pop1980-deaths1980-deaths1981-deaths1982-deaths1983-deaths1984-deaths1985-deaths1986) + (pop1990+deaths1989+deaths1988+deaths1987))/2;
gen pop1988 = ((pop1980-deaths1980-deaths1981-deaths1982-deaths1983-deaths1984-deaths1985-deaths1986-deaths1987) + (pop1990+deaths1989+deaths1988))/2;
gen pop1989 = ((pop1980-deaths1980-deaths1981-deaths1982-deaths1983-deaths1984-deaths1985-deaths1986-deaths1987-deaths1988) + (pop1990+deaths1989))/2;
gen pop1991 = pop1990-deaths1990;
gen pop1992 = pop1990-deaths1991-deaths1992;

reshape long pop deaths, i(sex birthyr ornp bpl) j(censusyear);

gen personyears = round(pop - (deaths/2));

gen deathrate = deaths/personyears;
gen survrate = 1-deathrate;
bysort censusyear: table birthyr ornp if sex==1, contents(mean deathrate);
bysort censusyear: table birthyr ornp if sex==2, contents(mean deathrate);

save deathrate80s, replace;

collapse (sum) personyears deaths, by(sex ornp censusyear);
gen deathrate = deaths/personyears;

bysort censusyear: tab ornp if sex==1, sum(deathrate);
bysort censusyear: tab ornp if sex==2, sum(deathrate);

collapse (sum) personyears deaths, by(sex ornp);
gen deathrate = deaths/personyears;
gen survrate = 1-deathrate;

tab ornp if sex==1, sum(deathrate);
tab ornp if sex==2, sum(deathrate);

clear;
use deathrate80s;
append using deathrate60s;
sum;

*keep only those younger than 65;
gen age = censusyear-birthyr;
keep if age<65;

*state of birth indicators;
gen nd= (bpl==38);
gen sd = (bpl==46);

gen lndeathrate = ln(deathrate);
gen lnsurvrate = ln(survrate);


xtset birthyr;
xtreg lndeathrate ornp i.censusyear sex nd sd, fe cluster(birthyr);
xtreg lndeathrate ornp i.censusyear nd sd if sex==1, fe cluster(birthyr);
xtreg lndeathrate ornp i.censusyear nd sd if sex==2, fe cluster(birthyr);

xtreg lnsurvrate ornp i.censusyear sex nd sd, fe cluster(birthyr);
sum survrate if e(sample);
xtreg lnsurvrate ornp i.censusyear nd sd if sex==1, fe cluster(birthyr);
sum survrate if e(sample);
xtreg lnsurvrate ornp i.censusyear nd sd if sex==2, fe cluster(birthyr);
sum survrate if e(sample);

xtreg lndeathrate ornp i.censusyear sex nd sd if censusyear<1965, fe cluster(birthyr);
tab ornp if sex==1 & censusyear<1965, sum(deathrate);
xtreg lndeathrate ornp i.censusyear nd sd if sex==1 & censusyear<1965, fe cluster(birthyr);
tab ornp if sex==2 & censusyear<1965, sum(deathrate);
xtreg lndeathrate ornp i.censusyear nd sd if sex==2 & censusyear<1965, fe cluster(birthyr);

xtreg lndeathrate ornp i.censusyear sex nd sd if censusyear>1965, fe cluster(birthyr);
tab ornp if sex==1 & censusyear>1965, sum(deathrate);
xtreg lndeathrate ornp i.censusyear nd sd if sex==1 & censusyear>1965, fe cluster(birthyr);
tab ornp if sex==2 & censusyear>1965, sum(deathrate);
xtreg lndeathrate ornp i.censusyear nd sd if sex==2 & censusyear>1965, fe cluster(birthyr);
clear;
